<template>
  <div class="edit-cell" @click="onFieldClick">
    <el-tooltip
      v-if="!editMode && !showInput"
      :placement="toolTipPlacement"
      :open-delay="toolTipDelay"
      :content="toolTipContent"
    >
      <div
        tabindex="0"
        class="cell-content"
        :class="{'edit-enabled-cell': canEdit}"
      >
        <!-- @keyup.enter="onFieldClick"-->
        <slot name="content" />
      </div>

    </el-tooltip>
    <!--@focus="onFieldClick"-->
    <el-input
      v-if="editMode || showInput"
      ref="input"
      v-model="model"
      placeholder="请输入内容"
      :class="error"
      @keyup.enter.native="onInputEnter"
      v-on="listeners"
    />
  </div>
</template>

<script>
import { multiply, abs } from '@/utils/tools'
import { validInteger } from '@/utils/validate'
export default {
  name: 'EditableCell',
  inheritAttrs: false,
  props: {
    value: {
      type: String,
      default: ''
    },
    toolTipContent: {
      type: String,
      default: '点击编辑'
    },
    toolTipDelay: {
      type: Number,
      default: 500
    },
    toolTipPlacement: {
      type: String,
      default: 'top-start'
    },
    showInput: {
      type: Boolean,
      default: false
    },
    editableComponent: {
      type: String,
      default: 'el-input'
    },
    closeEvent: {
      type: String,
      default: 'blur'
    },
    canEdit: {
      type: Boolean,
      default: false
    },
    rowData: {
      type: Object,
      default: function() {
        return {}
      }
    },
    flag: {
      type: String
    }
  },
  data() {
    return {
      editMode: false,
      error: ''
    }
  },
  computed: {
    model: {
      get() {
        return this.value
      },
      set(val) {
        this.$emit('input', val)
      }
    },
    listeners() {
      return {
        [this.closeEvent]: this.onInputExit,
        ...this.$listeners
      }
    }
  },
  methods: {
    onFieldClick() {
      if (this.canEdit) {
        this.editMode = true
        this.$nextTick(() => {
          const inputRef = this.$refs.input
          if (inputRef && inputRef.focus) {
            inputRef.focus()
          }
        })
      }
    },
    onInputEnter() {
      // enter 触发blur
      this.$refs.input.blur()
    },
    // 在这里做自定义校验
    onInputExit() {
      this.error = ''
      console.log(this.rowData)
      if (this.flag == 'bargain') {
        const rate = this.rowData.minEarningRate
        const price = abs(this.rowData.negotiatedPrice * (1 + abs(rate, 100)), 100)
        console.log('控制价：', price)
        console.log('输入价：', this.model)
        if (this.model < price) {
          this.$refs.input.focus()
          this.$message.error('不能小于最低盈利率')
          this.error = 'error'
          return false
        }
      } else {
        const ratio = this.rowData.batchRatio
        if (!validInteger(ratio)) {
          this.$message.error('请输入整数')
          return false
        }
        if (ratio < 0 || ratio > 100) {
          this.$message.error('请输入0～100之间的数字')
          return false
        }
      }
      this.editMode = false
      return false
    }
  }
}
</script>
<style>
  .cell-content {
    min-height: 28px;
    padding-left: 5px;
    padding-top: 2px;
    border: 1px solid transparent;
  }
  .error input{
    border-color: red!important;
  }
</style>
